@@ -69,10 +69,12 @@ ENJ = Coin("ENJ")
 ENS = Coin("ENS")
 EOS = Coin("EOS")
 EPS = Coin("EPS")
+EPX = Coin("EPX")
 ERN = Coin("ERN")
 ETC = Coin("ETC")
 ETH = Coin("ETH")
 FARM = Coin("FARM")
+FER = Coin("FER")
 FET = Coin("FET")
 FIL = Coin("FIL")
 FITFI = Coin("FITFI")
@@ -149,6 +151,7 @@ OMG = Coin("OMG")
 ONE = Coin("ONE")
 ONEINCH = Coin("1INCH")
 ONT = Coin("ONT")
+OP = Coin("OP")
 OXT = Coin("OXT")
 PAX = Coin("PAX")
 PAXG = Coin("PAXG")
