@@ -123,14 +123,19 @@ ENS_USDC = Pair("ENS_USDC", price_precision=3, quantity_precision=3)
 ENS_USDT = Pair("ENS_USDT", price_precision=3, quantity_precision=3)
 EOS_BTC = Pair("EOS_BTC", price_precision=8, quantity_precision=2)
 EOS_USDT = Pair("EOS_USDT", price_precision=4, quantity_precision=2)
+EPX_BTC = Pair("EPX_BTC", price_precision=10, quantity_precision=0)
+EPX_USDC = Pair("EPX_USDC", price_precision=7, quantity_precision=0)
+EPX_USDT = Pair("EPX_USDT", price_precision=7, quantity_precision=0)
 ERN_USDT = Pair("ERN_USDT", price_precision=4, quantity_precision=2)
 ETC_BTC = Pair("ETC_BTC", price_precision=7, quantity_precision=3)
+ETC_USDC = Pair("ETC_USDC", price_precision=3, quantity_precision=3)
 ETC_USDT = Pair("ETC_USDT", price_precision=3, quantity_precision=3)
 ETH_BTC = Pair("ETH_BTC", price_precision=6, quantity_precision=5)
 ETH_CRO = Pair("ETH_CRO", price_precision=2, quantity_precision=5)
 ETH_USDC = Pair("ETH_USDC", price_precision=2, quantity_precision=5)
 ETH_USDT = Pair("ETH_USDT", price_precision=2, quantity_precision=5)
 FARM_USDC = Pair("FARM_USDC", price_precision=2, quantity_precision=4)
+FER_USDC = Pair("FER_USDC", price_precision=6, quantity_precision=0)
 FET_USDT = Pair("FET_USDT", price_precision=5, quantity_precision=1)
 FIL_BTC = Pair("FIL_BTC", price_precision=7, quantity_precision=3)
 FIL_USDC = Pair("FIL_USDC", price_precision=3, quantity_precision=3)
@@ -151,11 +156,13 @@ FXS_USDT = Pair("FXS_USDT", price_precision=3, quantity_precision=2)
 GALA_BTC = Pair("GALA_BTC", price_precision=9, quantity_precision=1)
 GALA_USDC = Pair("GALA_USDC", price_precision=5, quantity_precision=1)
 GALA_USDT = Pair("GALA_USDT", price_precision=6, quantity_precision=0)
+GAL_USDC = Pair("GAL_USDC", price_precision=4, quantity_precision=2)
 GAL_USDT = Pair("GAL_USDT", price_precision=4, quantity_precision=2)
 GHST_USDC = Pair("GHST_USDC", price_precision=4, quantity_precision=2)
 GLMR_BTC = Pair("GLMR_BTC", price_precision=9, quantity_precision=2)
 GLMR_USDT = Pair("GLMR_USDT", price_precision=4, quantity_precision=2)
 GLM_USDT = Pair("GLM_USDT", price_precision=5, quantity_precision=1)
+GODS_USDC = Pair("GODS_USDC", price_precision=4, quantity_precision=2)
 GODS_USDT = Pair("GODS_USDT", price_precision=4, quantity_precision=2)
 GRT_BTC = Pair("GRT_BTC", price_precision=10, quantity_precision=1)
 GRT_USDT = Pair("GRT_USDT", price_precision=5, quantity_precision=2)
@@ -250,6 +257,8 @@ ONE_USDC = Pair("ONE_USDC", price_precision=5, quantity_precision=1)
 ONE_USDT = Pair("ONE_USDT", price_precision=5, quantity_precision=1)
 ONT_BTC = Pair("ONT_BTC", price_precision=8, quantity_precision=2)
 ONT_USDT = Pair("ONT_USDT", price_precision=4, quantity_precision=2)
+OP_BTC = Pair("OP_BTC", price_precision=9, quantity_precision=2)
+OP_USDT = Pair("OP_USDT", price_precision=4, quantity_precision=2)
 OXT_USDT = Pair("OXT_USDT", price_precision=5, quantity_precision=1)
 PAXG_USDT = Pair("PAXG_USDT", price_precision=2, quantity_precision=5)
 PENDLE_USDT = Pair("PENDLE_USDT", price_precision=5, quantity_precision=1)
@@ -278,6 +287,7 @@ RARI_USDT = Pair("RARI_USDT", price_precision=3, quantity_precision=3)
 RAY_USDT = Pair("RAY_USDT", price_precision=4, quantity_precision=2)
 REEF_USDT = Pair("REEF_USDT", price_precision=7, quantity_precision=0)
 REN_USDT = Pair("REN_USDT", price_precision=5, quantity_precision=2)
+REP_USDT = Pair("REP_USDT", price_precision=3, quantity_precision=3)
 REQ_USDT = Pair("REQ_USDT", price_precision=5, quantity_precision=1)
 RLC_USDT = Pair("RLC_USDT", price_precision=3, quantity_precision=3)
 RLY_USDT = Pair("RLY_USDT", price_precision=5, quantity_precision=2)
